==> backup_download.php?file=website_backup_2025-05-04_05-55-00.zip: product/index.php <==
<!DOCTYPE html>
<html lang="zh-CN">
  <?php include '../public/config.php'; ?>
  <?php require_once __DIR__ . '/../code/product_data.php'; ?>
  <?php require_once __DIR__ . '/../user/code/auth.php'; ?>
  <?php require_once __DIR__ . '/../code/product_init.php'; ?>
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>服务器产品 - 香港服务器|美国服务器|日本服务器|韩国服务器|台湾服务器</title>
    <meta name="description" content="景天云全线产品服务，包括香港服务器、美国服务器、全球服务器租用、托管和云计算服务">
    <meta name="keywords" content="服务器,云服务器,服务器租用,服务器托管,香港服务器,美国服务器">
    <?php echo getCommonCss(); ?>
    <link href="/public/css/product.css" rel="stylesheet">
    <link href="/public/css/product-enhanced.css" rel="stylesheet">
    <script src="/public/js/product.js" defer></script>
    <script src="/public/js/product-filter.js" defer></script>
  </head>
  <body>
    <!-- 顶部导航 -->
    <?php include '../public/header.php'; ?>
    <!-- 主内容区 -->
    <div class="main-content">
      <!-- Banner 区域（全宽） -->
      <?php include '../public/banner.php'; ?>
      <!-- 内容区域（固定宽度） -->
      <div class="product-content">
        <!-- 面包屑导航 -->
        <div class="breadcrumb">
          <a href="/">
            首页
          </a>
          <i class="material-icons">chevron_right</i>
          <span>服务器产品</span>
        </div>
        <!-- 产品过滤区 -->
        <div class="product-filter">
          <div class="filter-section">
            <div class="filter-title">地域分布</div>
            <div class="filter-options">
              <!-- 国家选项 -->
              <?php foreach ($parentRegions as $parent): ?>
              <a href="javascript:void(0);" class="filter-option country-option <?php echo $selectedParentForDisplay == $parent['id'] ? 'active' : ''; ?>"
                 data-parent="<?php echo $parent['id']; ?>" data-filter="parent_region" data-value="<?php echo $parent['id']; ?>">
                <?php echo $parent['name']; ?>
              </a>
              <?php endforeach; ?>
            </div>
          </div>
          <div class="filter-section" id="region-filter-section" style="<?php echo empty($childRegionsByParent[$selectedParentForDisplay]) ? 'display:none;' : ''; ?>">
            <div class="filter-title">城市/区域</div>
            <div class="filter-options">
              <?php foreach ($parentRegions as $parent): ?>
              <div class="region-group <?php echo $selectedParentForDisplay == $parent['id'] ? 'active' : ''; ?>" style="display: <?php echo $selectedParentForDisplay == $parent['id'] ? 'flex' : 'none'; ?>;"
                   data-parent="<?php echo $parent['id']; ?>">
                <?php if (isset($childRegionsByParent[$parent['id']])): ?>
                <?php foreach ($childRegionsByParent[$parent['id']] as $child): ?>
                <a href="javascript:void(0);"
                   class="filter-option <?php echo $selectedRegion == $child['id'] ? 'active' : ''; ?>"
                   data-filter="region" data-value="<?php echo $child['id']; ?>">
                  <?php echo $child['name']; ?>
                </a>
                <?php endforeach; ?>
                <?php else: ?>
                <!-- 如果没有子地区，不显示任何地区选项 -->
                <?php endif; ?>
              </div>
              <?php endforeach; ?>
            </div>
          </div>
          <!-- 为每个一级标签创建一个筛选区块 -->
          <?php foreach ($parentTags as $parent): ?>
          <div class="filter-section">
            <div class="filter-title"><?php echo htmlspecialchars($parent['name']); ?></div>
            <div class="filter-options">
              <?php if (isset($childTagsByParent[$parent['id']])): ?>
              <?php foreach ($childTagsByParent[$parent['id']] as $child): ?>
              <a href="javascript:void(0);" class="filter-option <?php echo $selectedTag == $child['id'] ? 'active' : ''; ?>"
                 data-filter="tag" data-value="<?php echo $child['id']; ?>">
                <?php echo htmlspecialchars($child['name']); ?>
              </a>
              <?php endforeach; ?>
              <?php else: ?>
              <!-- 如果没有子类型，显示"全部"选项 -->
              <a href="javascript:void(0);" class="filter-option active" data-filter="tag" data-value="0">
                全部
              </a>
              <?php endif; ?>
            </div>
          </div>
          <?php endforeach; ?>
          <div class="filter-section">
            <div class="filter-title">价格</div>
            <div class="filter-options">
              <?php foreach ($priceRanges as $range): ?>
              <a href="javascript:void(0);"
                 class="filter-option <?php echo ($selectedMinPrice == $range['min'] && $selectedMaxPrice == $range['max']) ? 'active' : ''; ?>"
                 data-filter="price" data-min="<?php echo $range['min']; ?>" data-max="<?php echo $range['max']; ?>">
                <?php echo $range['label']; ?>
              </a>
              <?php endforeach; ?>
            </div>
          </div>
          <!-- 筛选结果统计 -->
          <div id="filter-summary" class="filter-summary" style="display: none;">
            <div class="filter-count">符合您选择共计 <span id="product-count">0</span> 款产品</div>
            <a href="javascript:void(0);" id="clear-filters" class="clear-filters">
              <i class="material-icons" style="font-size: 16px; vertical-align: middle; margin-right: 4px;">close</i>清除重选
            </a>
          </div>
        </div>
        <!-- 排序选项 -->
        <div class="product-sort">
          <span class="sort-label">排序方式：</span>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'recommended' ? 'active' : ''; ?>" data-sort="recommended">
            默认
          </a>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'price' ? 'active' : ''; ?>" data-sort="price" data-current-order="<?php echo $sortOrder; ?>">
            价格 <i class="material-icons"><?php echo $priceIcon; ?></i>
          </a>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'created' ? 'active' : ''; ?>" data-sort="created" data-current-order="<?php echo $sortOrder; ?>">
            上架时间 <i class="material-icons"><?php echo $createdIcon; ?></i>
          </a>
          <div class="view-mode">
            <a href="#" class="view-mode-btn active" title="网格视图">
              <i class="material-icons">grid_view</i>
            </a>
            <a href="#" class="view-mode-btn" title="列表视图">
              <i class="material-icons">view_list</i>
            </a>
          </div>
        </div>
        <!-- 产品列表 -->
        <div class="product-list">
          <?php if (empty($products)): ?>
          <div class="no-products" style="text-align:center; padding:30px; font-size:18px;">暂无产品数据，请联系管理员添加产品。</div>
          <?php else: ?>
          <?php foreach ($products as $product): ?>
          <div class="product-card">
            <div class="product-title">
              <a href="/product/<?php echo $product['id']; ?>.html">
                <?php echo generateProductTitle($product, $areaNames, $allRegions, $parentRegions); ?>
              </a>
            </div>
            <div class=" product-specs">
              <!-- 第一列：编号/硬盘/防御/地区 -->
              <div class="specs-column">
                <div class="spec-row">
                  <span class="spec-label">编号:</span>
                  <span><?php echo formatProductId($product['id']); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">硬盘:</span>
                  <span><?php echo htmlspecialchars($product['disk'] ?? '未设置'); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">防御:</span>
                  <span><?php echo getDefenseDisplay($product['defense']); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">地区:</span>
                  <span><?php echo getRegionDisplay($product['region_id'], $areaNames); ?></span>
                </div>
              </div>
              <!-- 第二列：CPU/宽带/线路/内存 -->
              <div class="specs-column">
                <div class="spec-row">
                  <span class="spec-label">CPU:</span>
                  <span><?php echo htmlspecialchars($product['cpu'] ?? '未设置'); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">宽带:</span>
                  <span><?php echo htmlspecialchars($product['bandwidth'] ?? '未设置'); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">线路:</span>
                  <span><?php echo getLineDisplay($product['line_id'], $lineData); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">内存:</span>
                  <span><?php echo htmlspecialchars($product['memory'] ?? '未设置'); ?></span>
                </div>
              </div>
              <!-- 第三列：IP数/流量/价格/按钮 -->
              <div class="specs-column">
                <div class="spec-row">
                  <span class="spec-label">IP数:</span>
                  <span><?php echo htmlspecialchars($product['ip_count'] ?? '未设置'); ?>个</span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">流量:</span>
                  <span><?php echo getTrafficDisplay($product['traffic']); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">价格:</span>
                  <span class="unit"><?php echo getPriceDisplay($product['price'], $product['original_price'] ?? null); ?></span>
                </div>
                <div class="spec-row action-row">
                  <a href="/product/<?php echo $product['id']; ?>.html" class="btn btn-primary">
                    产品详情
                  </a>
                  <a href="<?php echo $GLOBALS['Telegram']; ?>" class="btn btn-outline" target="_blank">
                    申请测机
                  </a>
                </div>
              </div>
            </div>
          </div>
          <?php endforeach; ?>
          <?php endif; ?>
        </div>
        <!-- 分页 -->
        <?php echo generatePagination($currentPage, $totalPages); ?>
        <!-- 产品推荐 -->
      </div>
    </div>
    <!-- 页脚 -->
    <?php include '../public/footer.php'; ?>
    <?php include '../public/kf.php'; ?>
    <script src="/public/js/js.js"></script>
    <script src="/public/js/banner.js"></script>
    <script>
    // 在这里添加产品页面php变量到js的桥接代码
    // 这些变量会被product-filter.js使用
    const selectedTag = <?php echo $selectedTag ?: 0; ?>;
    const selectedRegion = <?php echo $selectedRegion ?: 0; ?>;
    const selectedParent = <?php echo $selectedParent ?: 0; ?>;
    const selectedMinPrice = <?php echo $selectedMinPrice ? "'" . $selectedMinPrice . "'" : 'null'; ?>;
    const selectedMaxPrice = <?php echo $selectedMaxPrice ? "'" . $selectedMaxPrice . "'" : 'null'; ?>;
    const sortBy = '<?php echo $sortBy ?: 'recommended'; ?>';
    const sortOrder = '<?php echo $sortOrder ?: ''; ?>';
    const currentPage = <?php echo $currentPage ?: 1; ?>;
    </script>
  </body>
</html>

==> backup_download.php?file=website_backup_2025-05-06_06-33-27.zip: product/index.php <==
<!DOCTYPE html>
<html lang="zh-CN">
  <?php 
  // 开启错误显示（仅用于调试，生产环境应移除）
  ini_set('display_errors', 1);
  error_reporting(E_ALL);
  
  include '../config/config.php';
  require_once __DIR__ . '/code/product_data.php';
  require_once __DIR__ . '/../user/code/auth.php';
  require_once __DIR__ . '/code/product_init.php';
  
  // 调试信息
  if (function_exists('logDebug')) {
    logDebug("产品页面 - 产品数据示例: " . (empty($products) ? "无数据" : print_r($products[0], true)));
    logDebug("产品页面 - 总数: $totalProducts, 总页数: $totalPages");
  }
  
  // 检查数据库连接
  global $db;
  if (!$db) {
    if (function_exists('logDebug')) {
      logDebug("产品页面 - 数据库连接失败");
    }
  } else {
    if (function_exists('logDebug')) {
      logDebug("产品页面 - 数据库连接成功");
    }
    // 执行一个简单的查询验证连接
    try {
      $testResult = $db->query("SELECT COUNT(*) FROM products WHERE status = 1")->fetchColumn();
      if (function_exists('logDebug')) {
        logDebug("产品页面 - 产品总数测试查询: $testResult");
      }
    } catch (Exception $e) {
      if (function_exists('logDebug')) {
        logDebug("产品页面 - 测试查询失败: " . $e->getMessage());
      }
    }
  }
  
  // DEBUG: 显示调试信息（仅用于开发环境，生产环境请移除）
  if (isset($_GET['debug']) && $_GET['debug'] == 1):
  ?>
  <div style="background: #f8f9fa; padding: 15px; margin: 10px; border: 1px solid #ddd; border-radius: 5px;">
    <h3>产品页面调试信息</h3>
    <p>总产品数: <?php echo $totalProducts; ?></p>
    <p>总页数: <?php echo $totalPages; ?></p>
    <p>当前页: <?php echo $currentPage; ?></p>
    <p>查询条件: <?php echo '<pre>' . print_r($filters, true) . '</pre>'; ?></p>
    <p>产品样本: <?php echo !empty($products) ? '<pre>' . print_r($products[0], true) . '</pre>' : '无数据'; ?></p>
  </div>
  <?php endif; ?>

  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>服务器产品 - 香港服务器|美国服务器|日本服务器|韩国服务器|台湾服务器</title>
    <meta name="description" content="全线产品服务，包括香港服务器、美国服务器、全球服务器租用、托管和云计算服务">
    <meta name="keywords" content="服务器,云服务器,服务器租用,服务器托管,香港服务器,美国服务器">
    <?php echo getCommonCss(); ?>
    <link href="/public/css/product.css" rel="stylesheet">
    <link href="/public/css/product-enhanced.css" rel="stylesheet">
    <script src="/public/js/product.js" defer></script>
    <script src="/public/js/product-filter.js" defer></script>
  </head>
  <body>
    <?php include '../public/header.php'; ?>
    <div class="main-content">
      <?php include '../public/banner.php'; ?>
      <div class="product-content">
        <div class="breadcrumb">
          <a href="/">
            首页
          </a>
          <i class="material-icons">chevron_right</i>
          <a href="/product">服务器产品</a>

        </div>
        <!-- 产品过滤区 -->
        <div class="product-filter">
          <div class="filter-section">
            <div class="filter-title">地域分布</div>
            <div class="filter-options">
              <!-- 国家选项 -->
              <?php foreach ($parentRegions as $parent): ?>
              <a href="javascript:void(0);" class="filter-option country-option <?php echo $selectedParentForDisplay == $parent['id'] ? 'active' : ''; ?>"
                 data-parent="<?php echo $parent['id']; ?>" data-filter="parent_region" data-value="<?php echo $parent['id']; ?>">
                <?php echo $parent['name']; ?>
              </a>
              <?php endforeach; ?>
            </div>
          </div>
          <div class="filter-section" id="region-filter-section" style="<?php echo empty($childRegionsByParent[$selectedParentForDisplay]) ? 'display:none;' : ''; ?>">
            <div class="filter-title">城市/区域</div>
            <div class="filter-options">
              <?php foreach ($parentRegions as $parent): ?>
              <div class="region-group <?php echo $selectedParentForDisplay == $parent['id'] ? 'active' : ''; ?>" style="display: <?php echo $selectedParentForDisplay == $parent['id'] ? 'flex' : 'none'; ?>;"
                   data-parent="<?php echo $parent['id']; ?>">
                <?php if (isset($childRegionsByParent[$parent['id']])): ?>
                <?php foreach ($childRegionsByParent[$parent['id']] as $child): ?>
                <a href="javascript:void(0);"
                   class="filter-option <?php echo $selectedRegion == $child['id'] ? 'active' : ''; ?>"
                   data-filter="region" data-value="<?php echo $child['id']; ?>">
                  <?php echo $child['name']; ?>
                </a>
                <?php endforeach; ?>
                <?php else: ?>
                <!-- 如果没有子地区，不显示任何地区选项 -->
                <?php endif; ?>
              </div>
              <?php endforeach; ?>
            </div>
          </div>
          <!-- 为每个一级标签创建一个筛选区块 -->
          <?php foreach ($parentTags as $parent): ?>
          <div class="filter-section">
            <div class="filter-title"><?php echo htmlspecialchars($parent['name']); ?></div>
            <div class="filter-options">
              <?php if (isset($childTagsByParent[$parent['id']])): ?>
              <?php foreach ($childTagsByParent[$parent['id']] as $child): ?>
              <a href="javascript:void(0);" class="filter-option <?php echo $selectedTag == $child['id'] ? 'active' : ''; ?>"
                 data-filter="tag" data-value="<?php echo $child['id']; ?>">
                <?php echo htmlspecialchars($child['name']); ?>
              </a>
              <?php endforeach; ?>
              <?php else: ?>
              <!-- 如果没有子类型，显示"全部"选项 -->
              <a href="javascript:void(0);" class="filter-option active" data-filter="tag" data-value="0">
                全部
              </a>
              <?php endif; ?>
            </div>
          </div>
          <?php endforeach; ?>
          <div class="filter-section">
            <div class="filter-title">价格</div>
            <div class="filter-options">
              <?php foreach ($priceRanges as $range): ?>
              <a href="javascript:void(0);"
                 class="filter-option <?php echo ($selectedMinPrice == $range['min'] && $selectedMaxPrice == $range['max']) ? 'active' : ''; ?>"
                 data-filter="price" data-min="<?php echo $range['min']; ?>" data-max="<?php echo $range['max']; ?>">
                <?php echo $range['label']; ?>
              </a>
              <?php endforeach; ?>
            </div>
          </div>
          <!-- 筛选结果统计 -->
          <div id="filter-summary" class="filter-summary" style="display: none;">
            <div class="filter-count">符合您选择共计 <span id="product-count">0</span> 款产品</div>
            <a href="javascript:void(0);" id="clear-filters" class="clear-filters">
              <i class="material-icons" style="font-size: 16px; vertical-align: middle; margin-right: 4px;">close</i>清除重选
            </a>
          </div>
        </div>
        <!-- 排序选项 -->
        <div class="product-sort">
          <span class="sort-label">排序方式：</span>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'recommended' ? 'active' : ''; ?>" data-sort="recommended">
            默认
          </a>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'price' ? 'active' : ''; ?>" data-sort="price" data-current-order="<?php echo $sortOrder; ?>">
            价格 <i class="material-icons"><?php echo $priceIcon; ?></i>
          </a>
          <a href="javascript:void(0);" class="sort-option <?php echo $sortBy == 'created' ? 'active' : ''; ?>" data-sort="created" data-current-order="<?php echo $sortOrder; ?>">
            上架时间 <i class="material-icons"><?php echo $createdIcon; ?></i>
          </a>
          <div class="view-mode">
            <a href="#" class="view-mode-btn active" title="网格视图">
              <i class="material-icons">grid_view</i>
            </a>
            <a href="#" class="view-mode-btn" title="列表视图">
              <i class="material-icons">view_list</i>
            </a>
          </div>
        </div>
        <!-- 产品列表 -->
        <div class="product-list">
          <?php 
          // 调试输出 - 输出实际查询到的产品数量
          if (isset($_GET['debug']) && $_GET['debug'] == 1) {
            echo '<div style="background:#f8f9fa; padding:10px; margin:10px 0; border-radius:5px;">';
            echo '实际产品数量: ' . (is_array($products) ? count($products) : '非数组');
            echo '<br>筛选条件: ' . print_r($filters, true);
            if (!empty($products) && is_array($products)) {
              echo '<br>第一个产品ID: ' . $products[0]['id'];
            }
            echo '</div>';
          }
          
          // 如果筛选条件没有结果，显示提示信息
          if (isset($showAllProducts) && $showAllProducts) {
            echo '<div style="background:#fff3cd; color:#856404; padding:10px; margin:10px 0; border-radius:5px; text-align:center;">';
            echo '没有找到符合筛选条件的产品，显示所有产品。';
            echo '</div>';
          }
          
          if (empty($products)): 
          ?>
          <div class="no-products" style="text-align:center; padding:30px; font-size:18px;">暂无产品数据，请联系管理员添加产品。</div>
          <?php else: ?>
          <?php foreach ($products as $product): ?>
          <div class="product-card">
            <div class="product-title">
              <a href="/product/<?php echo $product['id']; ?>.html">
                <?php echo generateProductTitle($product, $areaNames, $allRegions, $parentRegions); ?>
              </a>
            </div>
            <div class=" product-specs">
              <!-- 第一列：编号/硬盘/防御/地区 -->
              <div class="specs-column">
                <div class="spec-row">
                  <span class="spec-label">编号:</span>
                  <span><?php echo formatProductId($product['id']); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">硬盘:</span>
                  <span><?php echo htmlspecialchars($product['disk'] ?? '未设置'); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">防御:</span>
                  <span><?php echo getDefenseDisplay($product['defense']); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">地区:</span>
                  <span><?php echo getRegionDisplay($product['region_id'], $areaNames); ?></span>
                </div>
              </div>
              <!-- 第二列：CPU/宽带/线路/内存 -->
              <div class="specs-column">
                <div class="spec-row">
                  <span class="spec-label">CPU:</span>
                  <span><?php echo htmlspecialchars($product['cpu'] ?? '未设置'); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">宽带:</span>
                  <span><?php echo htmlspecialchars($product['bandwidth'] ?? '未设置'); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">线路:</span>
                  <span><?php echo getLineDisplay($product['line_id'], $lineData); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">内存:</span>
                  <span><?php echo htmlspecialchars($product['memory'] ?? '未设置'); ?></span>
                </div>
              </div>
              <!-- 第三列：IP数/流量/价格/按钮 -->
              <div class="specs-column">
                <div class="spec-row">
                  <span class="spec-label">IP数:</span>
                  <span><?php echo htmlspecialchars($product['ip_count'] ?? '未设置'); ?>个</span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">流量:</span>
                  <span><?php echo getTrafficDisplay($product['traffic']); ?></span>
                </div>
                <div class="spec-row">
                  <span class="spec-label">价格:</span>
                  <span class="unit"><?php echo getPriceDisplay($product['price'], $product['original_price'] ?? null); ?></span>
                </div>
                <div class="spec-row action-row">
                  <a href="/product/<?php echo $product['id']; ?>.html" class="btn btn-primary">
                    产品详情
                  </a>
                  <a href="<?php echo $GLOBALS['Telegram']; ?>" class="btn btn-outline" target="_blank">
                    申请测机
                  </a>
                </div>
              </div>
            </div>
          </div>
          <?php endforeach; ?>
          <?php endif; ?>
        </div>
        <!-- 分页 -->
        <?php echo generatePagination($currentPage, $totalPages); ?>
        <!-- 产品推荐 -->
      </div>
    </div>
    <!-- 页脚 -->
    <?php include '../public/footer.php'; ?>
    <?php include '../public/kf.php'; ?>
    <script src="/public/js/js.js"></script>
    <script src="/public/js/banner.js"></script>
    <script>
    // 在这里添加产品页面php变量到js的桥接代码
    // 这些变量会被product-filter.js使用
    const selectedTag = <?php echo $selectedTag ?: 0; ?>;
    const selectedRegion = <?php echo $selectedRegion ?: 0; ?>;
    const selectedParent = <?php echo $selectedParent ?: 0; ?>;
    const selectedMinPrice = <?php echo $selectedMinPrice ? "'" . $selectedMinPrice . "'" : 'null'; ?>;
    const selectedMaxPrice = <?php echo $selectedMaxPrice ? "'" . $selectedMaxPrice . "'" : 'null'; ?>;
    const sortBy = '<?php echo $sortBy ?: 'recommended'; ?>';
    const sortOrder = '<?php echo $sortOrder ?: ''; ?>';
    const currentPage = <?php echo $currentPage ?: 1; ?>;
    </script>
  </body>
</html>
